@@ -44,16 +44,9 @@ impl IndexUrl {
         let url = match split_scheme(path) {
             Some((scheme, ..)) => {
                 match Scheme::parse(scheme) {
-                    Some(scheme) => {
-                        if scheme.is_file() {
-                            // Ex) `file:///path/to/something/`
-                            VerbatimUrl::parse_url(path)?
-                        } else {
-                            // Ex) `https://pypi.org/simple/`
-                            // Remove a trailing slash if it exists.
-                            let normalized_path = path.strip_suffix('/').unwrap_or(path);
-                            VerbatimUrl::parse_url(normalized_path)?
-                        }
+                    Some(_) => {
+                        // Ex) `https://pypi.org/simple`
+                        VerbatimUrl::parse_url(path)?
                     }
                     None => {
                         // Ex) `C:\Users\user\index`
@@ -265,13 +258,20 @@ impl<'de> serde::de::Deserialize<'de> for IndexUrl {
 }
 
 impl From<VerbatimUrl> for IndexUrl {
-    fn from(url: VerbatimUrl) -> Self {
+    fn from(mut url: VerbatimUrl) -> Self {
         if url.scheme() == "file" {
             Self::Path(Arc::new(url))
-        } else if *url.raw() == *PYPI_URL {
-            Self::Pypi(Arc::new(url))
         } else {
-            Self::Url(Arc::new(url))
+            // Remove trailing slashes for consistency. They'll be re-added if necessary when
+            // querying the Simple API.
+            if let Ok(mut path_segments) = url.raw_mut().path_segments_mut() {
+                path_segments.pop_if_empty();
+            }
+            if *url.raw() == *PYPI_URL {
+                Self::Pypi(Arc::new(url))
+            } else {
+                Self::Url(Arc::new(url))
+            }
         }
     }
 }
@@ -462,6 +462,19 @@ impl<'a> IndexLocations {
             indexes
         }
     }
+
+    /// Add all authenticated sources to the cache.
+    pub fn cache_index_credentials(&self) {
+        for index in self.allowed_indexes() {
+            if let Some(credentials) = index.credentials() {
+                let credentials = Arc::new(credentials);
+                uv_auth::store_credentials(index.raw_url(), credentials.clone());
+                if let Some(root_url) = index.root_url() {
+                    uv_auth::store_credentials(&root_url, credentials.clone());
+                }
+            }
+        }
+    }
 }
 
 impl From<&IndexLocations> for uv_auth::Indexes {
